import { Injectable, ɵɵdefineInjectable, ɵɵinject, Component, NgModule, APP_INITIALIZER, EventEmitter, Input, Output, ViewChild, Inject, Directive } from '@angular/core';
import { __awaiter } from 'tslib';
import { Router, ActivatedRoute, RouterModule, NavigationEnd } from '@angular/router';
import { UserManager } from 'oidc-client';
import { BehaviorSubject, of, from, concat, Subscription, Subject, throwError } from 'rxjs';
import { map, mergeMap, take, filter, tap, debounceTime, distinctUntilChanged } from 'rxjs/operators';
import { HTTP_INTERCEPTORS } from '@angular/common/http';
import { CommonModule } from '@angular/common';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { MatToolbarModule } from '@angular/material/toolbar';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatInputModule, MatInput } from '@angular/material/input';
import { MatDividerModule } from '@angular/material/divider';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { FlexLayoutModule } from '@angular/flex-layout';
import { MatCardModule } from '@angular/material/card';

class User {
    constructor(username, fullName, email) {
        this.username = username;
        this.fullName = fullName;
        this.email = email;
    }
    static build(obj) {
        return new User(obj.username, obj.full_name, obj.email);
    }
}

class AuthConfiguration {
}
AuthConfiguration.decorators = [
    { type: Injectable }
];

class AuthService {
    constructor(_authConfiguration, _router, _activatedRoute) {
        this._authConfiguration = _authConfiguration;
        this._router = _router;
        this._activatedRoute = _activatedRoute;
        this._userSubject = new BehaviorSubject(null);
        this.isAuthenticated$ = this._getUser().pipe(map(u => !!u));
        this.user = this._getUser();
        this._userManager = new UserManager(this._getSettings());
        this._subscribeToEvents();
    }
    static _createArguments(state) {
        return { useReplaceToNavigate: true, data: state };
    }
    static _buildUser(user) {
        return user && User.build(user.profile);
    }
    getAccessToken() {
        return of(null)
            .pipe(mergeMap(() => from(this._userManager.getUser())), map(user => user && user.access_token));
    }
    populate() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.login({});
        });
    }
    login(state) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const user = yield this._userManager.signinSilent(AuthService._createArguments(state));
                this._userSubject.next(AuthService._buildUser(user));
                return state;
            }
            catch (silentError) {
                console.log('Silent authentication error: ', silentError);
                try {
                    yield this._userManager.signinRedirect(AuthService._createArguments(state));
                    return;
                }
                catch (redirectError) {
                    console.log('Redirect authentication error: ', redirectError);
                    return;
                }
            }
        });
    }
    completeLogin(url) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const user = yield this._userManager.signinCallback(url);
                this._userSubject.next(AuthService._buildUser(user));
                return user === null || user === void 0 ? void 0 : user.state;
            }
            catch (error) {
                console.log('There was an error signing in: ', error);
                return;
            }
        });
    }
    logout(state) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this._userManager.signoutRedirect(AuthService._createArguments(state));
                return;
            }
            catch (redirectLogoutError) {
                console.log('Redirect logout error: ', redirectLogoutError);
                return;
            }
        });
    }
    completeLogout(url) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this._userManager.signoutCallback(url);
                return response === null || response === void 0 ? void 0 : response.state;
            }
            catch (error) {
                console.log(`There was an error trying to log out '${error}'.`);
                return;
            }
        });
    }
    _getUser() {
        return concat(this._userSubject.pipe(take(1), filter(u => !!u)), this._getUserFromStorage().pipe(filter(u => !!u), tap(u => this._userSubject.next(u))), this._userSubject.asObservable());
    }
    _getUserFromStorage() {
        return of(null).pipe(mergeMap(_ => this._userManager.getUser()), map(u => u && User.build(u.profile)));
    }
    _getSettings() {
        return {
            authority: this._authConfiguration.authority,
            automaticSilentRenew: this._authConfiguration.automaticSilentRenew,
            client_id: this._authConfiguration.clientId,
            includeIdTokenInSilentRenew: this._authConfiguration.includeIdTokenInSilentRenew,
            post_logout_redirect_uri: this._authConfiguration.postLogoutRedirectUri,
            response_type: this._authConfiguration.responseType,
            scope: this._authConfiguration.scope,
            silent_redirect_uri: this._authConfiguration.silentRedirectUri,
            redirect_uri: this._authConfiguration.redirectUri
        };
    }
    _subscribeToEvents() {
        this._userManager.events.addUserSignedOut(() => this._removeUser());
        this._userManager.events.addAccessTokenExpired(() => {
            this._removeUser();
            this.populate().then();
        });
    }
    _removeUser() {
        this._userManager.removeUser().then(_ => {
            this._userSubject.next(null);
        });
    }
}
AuthService.ɵprov = ɵɵdefineInjectable({ factory: function AuthService_Factory() { return new AuthService(ɵɵinject(AuthConfiguration), ɵɵinject(Router), ɵɵinject(ActivatedRoute)); }, token: AuthService, providedIn: "root" });
AuthService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
AuthService.ctorParameters = () => [
    { type: AuthConfiguration },
    { type: Router },
    { type: ActivatedRoute }
];

const ReturnUrl = 'returnUrl';
const LoginPaths = {
    Login: 'login',
    LoginCallback: 'login-callback'
};
const LogoutPaths = {
    Logout: 'logout',
    LogoutCallback: 'logout-callback'
};

class LoginComponent {
    constructor(_activatedRoute, _auth, _router) {
        this._activatedRoute = _activatedRoute;
        this._auth = _auth;
        this._router = _router;
    }
    ngOnInit() {
        return __awaiter(this, void 0, void 0, function* () {
            const action = this._activatedRoute.snapshot.url[0];
            switch (action.path) {
                case LoginPaths.Login:
                    yield this._login(this._getReturnUrl());
                    break;
                case LoginPaths.LoginCallback:
                    yield this._processLoginCallback();
                    break;
                default:
                    throw new Error(`Invalid action ${action}`);
            }
        });
    }
    _login(returnUrl) {
        return __awaiter(this, void 0, void 0, function* () {
            const state = { returnUrl };
            const result = yield this._auth.login(state);
            if (!result) {
                return;
            }
            yield this._router.navigateByUrl(this._getReturnUrl(result), { replaceUrl: true });
        });
    }
    _processLoginCallback() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = window.location.href;
            const result = yield this._auth.completeLogin(url);
            yield this._router.navigateByUrl(this._getReturnUrl(result), { replaceUrl: true });
        });
    }
    _getReturnUrl(state) {
        var _a;
        const fromQuery = (_a = this._activatedRoute.snapshot.queryParams) === null || _a === void 0 ? void 0 : _a.ReturnUrl;
        if (fromQuery &&
            !(fromQuery.startsWith(`${window.location.origin}/`) ||
                /\/[^\/].*/.test(fromQuery))) {
            throw new Error('Invalid return url. The return url needs to have the same origin as the current page.');
        }
        return (state && state.returnUrl) ||
            fromQuery ||
            '/';
    }
}
LoginComponent.decorators = [
    { type: Component, args: [{
                template: ''
            },] }
];
LoginComponent.ctorParameters = () => [
    { type: ActivatedRoute },
    { type: AuthService },
    { type: Router }
];

class LogoutComponent {
    constructor(_activatedRoute, _auth, _router) {
        this._activatedRoute = _activatedRoute;
        this._auth = _auth;
        this._router = _router;
    }
    ngOnInit() {
        return __awaiter(this, void 0, void 0, function* () {
            const action = this._activatedRoute.snapshot.url[0];
            switch (action.path) {
                case LogoutPaths.Logout:
                    yield this._logout(this._getReturnUrl());
                    break;
                case LogoutPaths.LogoutCallback:
                    yield this._logoutCallback();
                    break;
                default:
                    throw new Error(`Invalid action ${action}`);
            }
        });
    }
    _logout(returnUrl) {
        return __awaiter(this, void 0, void 0, function* () {
            const state = { returnUrl };
            const isAuthenticated = yield this._auth.isAuthenticated$.pipe(take(1)).toPromise();
            if (!isAuthenticated) {
                return;
            }
            yield this._auth.logout(state);
        });
    }
    _logoutCallback() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = window.location.href;
            yield this._auth.completeLogout(url);
        });
    }
    _getReturnUrl(state) {
        var _a;
        const fromQuery = (_a = this._activatedRoute.snapshot.queryParams) === null || _a === void 0 ? void 0 : _a.ReturnUrl;
        if (fromQuery &&
            !(fromQuery.startsWith(`${window.location.origin}/`) ||
                /\/[^\/].*/.test(fromQuery))) {
            throw new Error('Invalid return url. The return url needs to have the same origin as the current page.');
        }
        return (state && state.returnUrl) ||
            fromQuery ||
            '/';
    }
}
LogoutComponent.decorators = [
    { type: Component, args: [{
                template: ''
            },] }
];
LogoutComponent.ctorParameters = () => [
    { type: ActivatedRoute },
    { type: AuthService },
    { type: Router }
];

class AuthInterceptor {
    constructor(auth) {
        this.auth = auth;
        this.processRequestWithToken = (token, req, next) => {
            if (!!token) {
                req = req.clone({
                    setHeaders: { Authorization: `Bearer ${token}` }
                });
            }
            return next.handle(req);
        };
    }
    intercept(req, next) {
        return this.auth.getAccessToken().pipe(mergeMap(token => this.processRequestWithToken(token, req, next)));
    }
}
AuthInterceptor.decorators = [
    { type: Injectable }
];
AuthInterceptor.ctorParameters = () => [
    { type: AuthService }
];

const routes = [
    { path: LoginPaths.Login, component: LoginComponent },
    { path: LoginPaths.LoginCallback, component: LoginComponent },
    { path: LogoutPaths.Logout, component: LogoutComponent },
    { path: LogoutPaths.LogoutCallback, component: LogoutComponent },
];
// @dynamic
class AuthModule {
    static forRoot(config) {
        return ({
            ngModule: AuthModule,
            providers: [
                {
                    provide: AuthConfiguration,
                    useExisting: config
                }
            ]
        });
    }
}
AuthModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    RouterModule.forRoot(routes)
                ],
                declarations: [
                    LoginComponent,
                    LogoutComponent
                ],
                providers: [
                    {
                        provide: HTTP_INTERCEPTORS,
                        useClass: AuthInterceptor,
                        multi: true
                    },
                    {
                        provide: APP_INITIALIZER,
                        useFactory: authSilentSignin,
                        deps: [AuthService],
                        multi: true
                    }
                ]
            },] }
];
function authSilentSignin(auth) {
    return () => auth.populate();
}

class AuthorizeGuard {
    constructor(_auth, _router) {
        this._auth = _auth;
        this._router = _router;
        this.handleAuthorization = (isAuthenticated, state) => {
            if (!isAuthenticated) {
                this._router.navigate([LoginPaths.Login], {
                    queryParams: { ReturnUrl: state.url }
                }).then();
            }
        };
    }
    canActivate(_next, state) {
        return this._auth.isAuthenticated$
            .pipe(tap(isAuthenticated => this.handleAuthorization(isAuthenticated, state)));
    }
}
AuthorizeGuard.ɵprov = ɵɵdefineInjectable({ factory: function AuthorizeGuard_Factory() { return new AuthorizeGuard(ɵɵinject(AuthService), ɵɵinject(Router)); }, token: AuthorizeGuard, providedIn: "root" });
AuthorizeGuard.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
AuthorizeGuard.ctorParameters = () => [
    { type: AuthService },
    { type: Router }
];

var AvatarStyle;
(function (AvatarStyle) {
    AvatarStyle[AvatarStyle["normal"] = 0] = "normal";
    AvatarStyle[AvatarStyle["grayDashedBorder"] = 1] = "grayDashedBorder";
    AvatarStyle[AvatarStyle["gray"] = 2] = "gray";
})(AvatarStyle || (AvatarStyle = {}));
var FileUploadError;
(function (FileUploadError) {
    FileUploadError[FileUploadError["incorrectType"] = 0] = "incorrectType";
    FileUploadError[FileUploadError["multipleFiles"] = 1] = "multipleFiles";
})(FileUploadError || (FileUploadError = {}));

class AvatarComponent {
    constructor() {
        this.enableUpload = false;
        this.size = 40;
        this.alt = 'avatar';
        this.sideMargin = 10;
        this.background = '#FFFFFF';
        this.color = '#748FFC';
        this.avatarStyle = AvatarStyle.normal;
        this.showBorder = true;
        this.fileSelected = new EventEmitter();
        this.uploadError = new EventEmitter();
        this._availableUploadFormats = [
            'image/jpeg'
        ];
    }
    ngOnInit() {
    }
    get imageUploaderBorderRadius() {
        return `0 0 ${this.size}px ${this.size}px`;
    }
    get imageUploaderHeight() {
        return `${this.size / 2}px`;
    }
    get margin() {
        return `0 ${this.sideMargin}px`;
    }
    get border() {
        if (this.source || !this.showBorder) {
            return 'none';
        }
        if (this.avatarStyle === AvatarStyle.grayDashedBorder) {
            return `2px dashed rgba(0, 0, 0, 0.38)`;
        }
        return this.source ? 'none' : `1px ${this.color} solid`;
    }
    get grayStyles() {
        if (this.avatarStyle === AvatarStyle.gray) {
            return {
                '-webkit-filter': 'grayscale(100%)',
                filter: 'grayscale(100%)',
            };
        }
        return {};
    }
    get getFontSize() {
        return this.fontSize ? `${this.fontSize}px` : 'inherit';
    }
    getMonogram() {
        var _a, _b, _c, _d;
        if (!this.text) {
            return;
        }
        const arr = this.text.split(' ');
        const first = (_b = (_a = arr[0]) === null || _a === void 0 ? void 0 : _a.charAt(0)) !== null && _b !== void 0 ? _b : '';
        const second = (_d = (_c = arr[1]) === null || _c === void 0 ? void 0 : _c.charAt(0)) !== null && _d !== void 0 ? _d : '';
        return first + second;
    }
    getSizePx() {
        return `${this.size}px`;
    }
    openFileDialog() {
        this.fileSelectDialog.nativeElement.click();
    }
    onFileSelected($event) {
        if ($event.target.files.length === 0) {
            return;
        }
        if ($event.target.files.length > 1) {
            this.uploadError.emit(FileUploadError.multipleFiles);
            return;
        }
        const file = $event.target.files[0];
        if (!this._availableUploadFormats.find(type => file.type === type)) {
            this.uploadError.emit(FileUploadError.incorrectType);
            return;
        }
        this.fileSelected.emit(file);
    }
}
AvatarComponent.decorators = [
    { type: Component, args: [{
                selector: 'pixo-avatar',
                template: "<div class=\"px-avatar\"\n     [style.margin]=\"margin\"\n     [style.width]=\"getSizePx()\"\n     [style.height]=\"getSizePx()\"\n     [style.background]=\"background\"\n     [style.border]=\"border\"\n     [style.fontSize]=\"getFontSize\"\n     [style.color]=\"color\">\n  <img *ngIf=\"source;else  monogram\"\n       [style.width]=\"getSizePx()\"\n       [style.height]=\"getSizePx()\"\n       [style.borderRadius]=\"'50%'\"\n       [alt]=\"alt\"\n       [ngStyle]=\"grayStyles\"\n       [src]=\"source\">\n\n  <ng-template #monogram>\n    <div [style.textTransform]=\"'uppercase'\"> {{getMonogram()}}</div>\n  </ng-template>\n\n\n  <div *ngIf=\"enableUpload\" class=\"px-av-upload\"\n       [style.height]=\"imageUploaderHeight\"\n       [style.borderRadius]=\"imageUploaderBorderRadius\"\n       [style.width]=\"getSizePx()\">\n    <button mat-icon-button (click)=\"openFileDialog()\"><mat-icon>photo_camera</mat-icon></button>\n    <input hidden #fileSelectDialog type=\"file\" accept=\"image/*\" (change)=\"onFileSelected($event)\"/>\n  </div>\n</div>\n",
                styles: [".px-avatar{border-radius:50%;position:relative;cursor:pointer}.px-av-upload,.px-avatar{display:flex;align-items:center;justify-content:center}.px-av-upload{background-color:rgba(0,0,0,.38);position:absolute;box-sizing:border-box;bottom:0}.px-av-upload .mat-icon-button{width:20px;height:20px;line-height:0}.px-av-upload .mat-icon-button mat-icon{font-size:20px;height:20px;width:20px}"]
            },] }
];
AvatarComponent.ctorParameters = () => [];
AvatarComponent.propDecorators = {
    enableUpload: [{ type: Input }],
    size: [{ type: Input }],
    source: [{ type: Input }],
    alt: [{ type: Input }],
    sideMargin: [{ type: Input }],
    background: [{ type: Input }],
    color: [{ type: Input }],
    text: [{ type: Input }],
    avatarStyle: [{ type: Input }],
    fontSize: [{ type: Input }],
    showBorder: [{ type: Input }],
    fileSelected: [{ type: Output }],
    uploadError: [{ type: Output }],
    fileSelectDialog: [{ type: ViewChild, args: ['fileSelectDialog',] }]
};

class AvatarModule {
}
AvatarModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    MatIconModule,
                    MatButtonModule
                ],
                declarations: [AvatarComponent],
                exports: [AvatarComponent],
                entryComponents: [AvatarComponent]
            },] }
];

class ToolbarService {
}
ToolbarService.decorators = [
    { type: Injectable }
];

class ProfileMenuComponent {
    constructor(ref, data) {
        this.ref = ref;
        this.data = data;
    }
    ngOnInit() {
        const dialogPosition = this.data.direction === 'rtl' ?
            { top: '8px', left: '40px' }
            : { top: '8px', right: '40px' };
        this.ref.updatePosition(dialogPosition);
    }
}
ProfileMenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'pixo-profile-menu',
                template: "<div fxLayout=\"column\" fxLayoutAlign=\"center center\" [style.margin]=\"'0 -24px'\" [dir]=\"data.direction\">\n  <pixo-avatar class=\"px-tb-hdl-4\"\n              [text]=\"data.username\"\n              [background]=\"'#748FFC'\"\n              [color]=\"'white'\"\n              [showBorder]=\"false\"\n              [size]=\"60\" [alt]=\"''\"\n              [enableUpload]=\"true\">\n  </pixo-avatar>\n  <span class=\"px-tb-sbt-1\" [style.marginTop]=\"'8px'\">{{data.username}}</span>\n  <span class=\"px-tb-cpt px-tb-o-06\" [style.marginTop]=\"'4px'\">{{data.email}}</span>\n  <button mat-button mat-dialog-close=\"true\"\n          class=\"px-tb-menu-pr-item px-tb-btn\" [style.marginTop]=\"'16px'\"\n          routerLink=\"{{data.accountMenu.primaryItem.route}}\">\n    <mat-icon>{{data.accountMenu.primaryItem.matIcon}}</mat-icon>\n    {{data.accountMenu.primaryItem.displayName}}\n  </button>\n  <mat-divider class=\"px-tb-w-100\"></mat-divider>\n  <div *ngFor=\"let item of data.accountMenu.items\" class=\"px-tb-w-100\">\n    <button mat-button mat-dialog-close=\"true\"\n            class=\"px-tb-menu-sec-item px-tb-btn\"\n            routerLink=\"{{item.route}}\">\n      <mat-icon>{{item.matIcon}}</mat-icon>\n      {{item.displayName}}\n    </button>\n    <mat-divider class=\"px-tb-w-100\"></mat-divider>\n  </div>\n  <div fxLayout=\"row\" fxLayoutAlign=\"center center\" class=\"px-tb-cpt px-tb-o-06\" [style.marginTop]=\"'16px'\">\n    <div>\n      <a routerLink=\"{{data.accountMenu.privacyPolicy.route}}\">\n        {{data.accountMenu.privacyPolicy.displayName}}\n      </a>\n    </div>\n    <div [style.margin]=\"'0 10px'\">\u00B7</div>\n    <div>\n      <a routerLink=\"{{data.accountMenu.termsOfUse.route}}\">\n        {{data.accountMenu.termsOfUse.displayName}}\n      </a>\n    </div>\n  </div>\n</div>\n",
                styles: [".px-tb-menu-pr-item{width:140px;height:36px;border:1px solid #018786;border-radius:4px;color:#018786;margin-bottom:16px}.px-tb-menu-sec-item{width:100%;height:48px}::ng-deep pixo-profile-menu a{color:inherit;text-decoration:none}"]
            },] }
];
ProfileMenuComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];

class Common {
    constructor(activatedRoute, router) {
        this.activatedRoute = activatedRoute;
        this.router = router;
        this.subscription = new Subscription();
    }
    subscribeToRouteData(callback) {
        this.subscription.add(this.router.events
            .pipe(filter(event => event instanceof NavigationEnd), map(() => this.activatedRoute), map(route => {
            while (route.firstChild) {
                route = route.firstChild;
            }
            return route;
        }))
            .pipe(filter(route => route.outlet === 'primary'), mergeMap(route => route.data))
            .subscribe(callback));
    }
    unsubscribe() {
        this.subscription.unsubscribe();
    }
}

class ToolbarComponent extends Common {
    constructor(toolbar, dialog, router, activatedRoute) {
        super(activatedRoute, router);
        this.toolbar = toolbar;
        this.dialog = dialog;
        this.enabled = false;
        this.keyUp = new Subject();
        this.search = new EventEmitter();
        this._subscribeToData();
    }
    ngOnInit() {
        this.keyUp.pipe(debounceTime(this.toolbar.search.debounceTime), distinctUntilChanged(), tap((e) => {
            var _a;
            this.search.emit((_a = e.target) === null || _a === void 0 ? void 0 : _a.value);
        })).subscribe();
    }
    openMenu() {
        if (this._dialogRef) {
            this._dialogRef.close();
            this._dialogRef = undefined;
        }
        this._dialogRef = this.dialog.open(ProfileMenuComponent, {
            width: '320px',
            height: '310px',
            data: {
                accountMenu: this.toolbar.accountMenu,
                username: this.username,
                email: this.email,
                direction: this.direction
            }
        });
    }
    _subscribeToData() {
        const callback = (event) => {
            if (event.hasOwnProperty('pixoToolbarEnabled')) {
                this.enabled = event.pixoToolbarEnabled;
            }
            else {
                this.enabled = true;
            }
        };
        this.subscribeToRouteData(callback);
    }
}
ToolbarComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'pixo-toolbar',
                template: "<mat-toolbar class=\"px-tb z-index\" [dir]=\"direction\" *ngIf=\"enabled\">\n  <div class=\"px-tb-l\">\n    <div class=\"px-tb-logo\">\n      <img class src=\"{{toolbar.logo.source}}\" alt=\"{{toolbar.logo.alt}}\"/>\n    </div>\n    <button mat-icon-button class=\"px-tb-burger\" [dir]=\"direction\">\n      <mat-icon>dehaze</mat-icon>\n    </button>\n    <span class=\"px-tb-title\">MyCompany1</span>\n  </div>\n  <div class=\"px-tb-r\">\n    <mat-form-field appearance=\"outline\" class=\"px-tb-search\">\n      <label>\n        <input (keyup)='keyUp.next($event)' matInput placeholder=\"{{toolbar.search.placeholder}}\"/>\n      </label>\n      <mat-icon matPrefix>search</mat-icon>\n    </mat-form-field>\n    <button mat-icon-button [style.margin]=\"'0 20px'\">\n      <mat-icon>apps</mat-icon>\n    </button>\n    <button mat-icon-button>\n      <mat-icon>notifications_none</mat-icon>\n    </button>\n    <pixo-avatar (click)=\"openMenu()\"  [text]=\"username\"\n                [color]=\"'white'\" [alt]=\"''\" [background]=\"'#748FFC'\"\n                [sideMargin]=\"20\" [showBorder]=\"false\" [avatarStyle]=\"0\">\n    </pixo-avatar>\n  </div>\n</mat-toolbar>\n",
                styles: ["::ng-deep:root{--px-tb-h:56px}.px-tb{background:#364fc7;height:var(--px-tb-h);top:0!important;position:fixed;display:flex;align-items:center;justify-content:space-between;flex-direction:row;color:#fff!important;padding:0 20px}.px-tb.z-index{z-index:1}.px-tb-l{align-items:center}.px-tb-l,.px-tb-r{display:flex;justify-content:center}.px-tb-r{align-items:flex-start}.px-tb-logo{width:40px!important;margin-right:0!important;margin-left:0!important;align-items:center;display:flex}::ng-deep pixo-toolbar .px-tb-logo img{width:40px;height:40px}.px-tb-title{font-weight:400;font-size:24px;line-height:24px;letter-spacing:.18px}::ng-deep .px-tb .mat-form-field-infix{padding:0}::ng-deep .mat-form-field-wrapper{padding:0;margin:0}.px-tb .mat-form-field{font-size:14px}.mat-mini-fab:not([class*=mat-elevation-z]),.px-tb .mat-fab:not([class*=mat-elevation-z]){box-shadow:none}.px-tb-search{width:328px;height:36px;border-radius:4px;margin:0 40px}button.px-tb-burger[dir=rtl]{margin-right:40px;margin-left:15px}button.px-tb-burger[dir=ltr]{margin-right:15px;margin-left:40px}::ng-deep mat-toolbar.px-tb .mat-form-field-appearance-outline .mat-form-field-outline{background-color:#7a89cd!important;border-radius:5px}::ng-deep .px-tb .mat-form-field-flex>.mat-form-field-infix{padding:.6em 0!important;border-top:.5em solid transparent}.px-tb .mat-form-field .mat-icon{color:#adb6e0}.px-tb ::-moz-placeholder{color:hsla(0,0%,100%,.74);opacity:1}.px-tb :-ms-input-placeholder{color:hsla(0,0%,100%,.74);opacity:1}.px-tb ::placeholder{color:hsla(0,0%,100%,.74);opacity:1}::ng-deep .px-tb-search .mat-form-field-infix{margin-right:15px}::ng-deep .px-tb-hdl-4{font-size:34px!important;line-height:36px!important}::ng-deep .px-tb-sbt-1{font-size:16px!important;line-height:24px!important;letter-spacing:.15px!important}::ng-deep .px-tb-cpt{font-weight:600!important;font-size:12px!important;line-height:16px!important;letter-spacing:.4px!important}::ng-deep .px-tb-o-06{color:rgba(0,0,0,.6)}::ng-deep .px-tb-btn{font-weight:700!important;font-size:14px!important;line-height:16px!important;letter-spacing:1.25px!important;text-transform:uppercase!important}::ng-deep .px-tb-w-100{width:100%!important}::ng-deep.cdk-overlay-container{z-index:5001}"]
            },] }
];
ToolbarComponent.ctorParameters = () => [
    { type: ToolbarService },
    { type: MatDialog },
    { type: Router },
    { type: ActivatedRoute }
];
ToolbarComponent.propDecorators = {
    search: [{ type: Output }],
    title: [{ type: Input }],
    direction: [{ type: Input }],
    username: [{ type: Input }],
    email: [{ type: Input }]
};

class ToolbarModule {
    static forRoot(config) {
        return ({
            ngModule: ToolbarModule,
            providers: [
                {
                    provide: ToolbarService,
                    useExisting: config
                }
            ]
        });
    }
}
ToolbarModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    RouterModule,
                    FlexLayoutModule,
                    MatToolbarModule,
                    MatIconModule,
                    MatFormFieldModule,
                    MatInputModule,
                    MatButtonModule,
                    MatDividerModule,
                    MatDialogModule,
                    AvatarModule
                ],
                declarations: [
                    ToolbarComponent,
                    ProfileMenuComponent
                ],
                entryComponents: [ProfileMenuComponent],
                exports: [ToolbarComponent]
            },] }
];

class SideNavigationService {
}
SideNavigationService.decorators = [
    { type: Injectable }
];

class SideNavigationComponent extends Common {
    constructor(sidenav, router, activatedRoute) {
        super(activatedRoute, router);
        this.sidenav = sidenav;
        this.enabled = true;
        this._subscribeToData();
    }
    ngOnDestroy() {
        this.unsubscribe();
    }
    itemIsActive(route) {
        const urlTree = this.router.createUrlTree([route]);
        return this.router.isActive(urlTree, false);
    }
    _subscribeToData() {
        const callback = (event) => {
            if (event.hasOwnProperty('pixoSidenavEnabled')) {
                this.enabled = event.pixoSidenavEnabled;
            }
            else {
                this.enabled = true;
            }
        };
        this.subscribeToRouteData(callback);
    }
}
SideNavigationComponent.decorators = [
    { type: Component, args: [{
                selector: 'pixo-side-navigation',
                template: "<div class=\"pixo-sidenav z-index\" *ngIf=\"enabled\">\n  <ng-container *ngFor=\"let item of sidenav.items\">\n    <ng-container *ngTemplateOutlet=\"itemTemplate; context: {item: item}\"></ng-container>\n  </ng-container>\n</div>\n\n<ng-template #itemTemplate let-item='item'>\n  <ng-container *ngIf=\"!(itemIsActive(item.route) && item.children?.length > 0)\">\n    <div fxLayout=\"column\" fxLayoutAlign=\"center center\"\n         [routerLink]=\"item.route\"\n         [routerLinkActive]=\"'pixo-sidenav_item-active'\"\n         class=\"pixo-sidenav_item\">\n      <mat-icon>{{item.icon}}</mat-icon>\n      <span>{{item.displayName}}</span>\n    </div>\n  </ng-container>\n  <ng-container *ngIf=\"itemIsActive(item.route) && item.children?.length > 0\">\n    <div fxLayout=\"column\" fxLayoutAlign=\"center center\"\n         *ngFor=\"let child of item.children\"\n         [routerLink]=\"child.route\"\n         [routerLinkActive]=\"'pixo-sidenav_item-active'\"\n         class=\"pixo-sidenav_item pixo-sidenav_item_children\">\n      <mat-icon>{{child.icon}}</mat-icon>\n      <span>{{child.displayName}}</span>\n    </div>\n  </ng-container>\n</ng-template>\n",
                styles: ["::ng-deep:root{--px-sn-w:80px}.pixo-sidenav{width:80px;background:#bac8ff;height:calc(100vh - 56px);padding:15px 0 20px;color:#364fc7;position:sticky;box-shadow:0 4px 5px rgba(0,0,0,.14),0 1px 10px rgba(0,0,0,.12),0 2px 4px rgba(0,0,0,.2);top:56px}.pixo-sidenav.z-index{z-index:1}.pixo-sidenav_item{min-height:56px;padding:8px 15px}.pixo-sidenav_item:hover{background:#edf2ff;cursor:pointer}.pixo-sidenav_item-selected{color:#00b3a6;background:#edf2ff}.pixo-sidenav_item span{font-style:normal;font-weight:600;font-size:12px;line-height:16px;text-align:center;letter-spacing:.4px}.pixo-sidenav_item-active{color:#00b3a6}.pixo-sidenav_item_children{background:#edf2ff}"]
            },] }
];
SideNavigationComponent.ctorParameters = () => [
    { type: SideNavigationService },
    { type: Router },
    { type: ActivatedRoute }
];

const components = [
    SideNavigationComponent
];
class SideNavigationModule {
    static forRoot(config) {
        return ({
            ngModule: SideNavigationModule,
            providers: [
                {
                    provide: SideNavigationService,
                    useExisting: config
                }
            ]
        });
    }
}
SideNavigationModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    RouterModule,
                    FlexLayoutModule,
                    MatCardModule,
                    MatIconModule
                ],
                declarations: components,
                exports: components
            },] }
];

class FeedbackComponent {
    constructor() {
    }
}
FeedbackComponent.decorators = [
    { type: Component, args: [{
                selector: 'pixo-feedback',
                template: "<div class=\"px-feedback\" fxLayoutAlign=\"center center\">\n  <button mat-fab class=\"px-message-button\">\n    <mat-icon>feedback</mat-icon>\n  </button>\n</div>\n\n",
                styles: [".px-feedback{position:fixed;width:100px;bottom:5vw;z-index:5001}.px-message-button{background-color:#03dac5;color:#000}"]
            },] }
];
FeedbackComponent.ctorParameters = () => [];

class FeedbackModule {
}
FeedbackModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    FlexLayoutModule,
                    MatIconModule,
                    MatButtonModule
                ],
                declarations: [FeedbackComponent],
                exports: [FeedbackComponent]
            },] }
];

class AutofocusDirective {
    constructor(_input) {
        this._input = _input;
    }
    ngOnInit() {
        if (!this._input) {
            throwError('Wrong input item');
        }
        else {
            setTimeout(() => this._input.focus());
        }
    }
}
AutofocusDirective.decorators = [
    { type: Directive, args: [{
                selector: '[pixoAutofocus]'
            },] }
];
AutofocusDirective.ctorParameters = () => [
    { type: MatInput }
];

class AutofocusDirectiveModule {
}
AutofocusDirectiveModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AutofocusDirective],
                exports: [AutofocusDirective],
            },] }
];

const components$1 = [
    AvatarModule,
    ToolbarModule,
    SideNavigationModule,
    FeedbackModule,
    AuthModule,
    AutofocusDirectiveModule
];
class PixoUiInfraModule {
}
PixoUiInfraModule.decorators = [
    { type: NgModule, args: [{
                imports: components$1,
                exports: components$1
            },] }
];

/*
 * Public API Surface of px-all-px
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AuthModule, AuthService, AuthorizeGuard, AutofocusDirective, AutofocusDirectiveModule, AvatarComponent, AvatarModule, AvatarStyle, FeedbackComponent, FeedbackModule, FileUploadError, PixoUiInfraModule, SideNavigationComponent, SideNavigationModule, SideNavigationService, ToolbarComponent, ToolbarModule, ToolbarService, User, authSilentSignin, LoginPaths as ɵa, LogoutPaths as ɵb, LoginComponent as ɵc, AuthConfiguration as ɵd, LogoutComponent as ɵe, AuthInterceptor as ɵf, Common as ɵg, ProfileMenuComponent as ɵh };
//# sourceMappingURL=pixo-ui-infra.js.map
